==> easyCrystallography-0.1.0.tar.gz: easyCrystallography-0.1.0/README.md <==
# [![License][50]][51] [![Release][32]][33] [![Downloads][70]][71] [![CI Build][20]][21] 

[![CodeFactor][83]][84] [![Lines of code][81]](<>) [![Total lines][80]](<>) [![Files][82]](<>)


<img height="80"><img src="https://raw.githubusercontent.com/easyScience/easyCrystallography/develop/resources/images/ec_logo.svg" height="65">

**easyCrystallography** is a library that can be used for the generation and manipulation of crystal structures.

## Install

**easyCrystallography** can be downloaded using pip:

```pip install easyCrystallography```

Or direct from the repository:

```pip install https://github.com/easyScience/easyCrystallography```

## Test

After installation, launch the test suite:

```python -m pytest```

[//]: # (## Documentation)

[//]: # ()
[//]: # (Documentation can be found at:)

[//]: # ()
[//]: # ([https://easyScience.github.io/easyCore]&#40;https://easyScience.github.io/easyCore&#41;)

## Contributing
We absolutely welcome contributions. **easyCore** is maintained by the ESS and on a volunteer basis and thus we need to foster a community that can support user questions and develop new features to make this software a useful tool for all users while encouraging every member of the community to share their ideas.

## License
While **easyCore** is under the BSD-3 license

<!---CI Build Status--->

[20]: https://github.com/easyScience/easyCrystallography/workflows/CI%20using%20pip/badge.svg

[21]: https://github.com/easyScience/easyCrystallography/actions


<!---Release--->

[32]: https://img.shields.io/pypi/v/easyCrystallography.svg

[33]: https://pypi.org/project/easyCrystallography


<!---License--->

[50]: https://img.shields.io/github/license/easyScience/easyCrystallography.svg

[51]: https://github.com/easyScience/easyCrystallography/blob/master/LICENSE.md


<!---Downloads--->

[70]: https://img.shields.io/pypi/dm/easyCrystallography.svg

[71]: https://pypi.org/project/easyCrystallography

<!---Code statistics--->

[80]: https://tokei.rs/b1/github/easyScience/easyCrystallography

[81]: https://tokei.rs/b1/github/easyScience/easyCrystallography?category=code

[82]: https://tokei.rs/b1/github/easyScience/easyCrystallography?category=files

[83]: https://www.codefactor.io/repository/github/easyscience/easyCrystallography/badge

[84]: https://www.codefactor.io/repository/github/easyscience/easyCrystallography

==> easyCrystallography-0.1.2.tar.gz: easyCrystallography-0.1.2/README.md <==
# [![License][50]][51] [![Release][32]][33] [![Downloads][70]][71] [![CI Build][20]][21] 

[![CodeFactor][83]][84] [![Codecov][85]][86]
[![Lines of code][81]](<>) [![Total lines][80]](<>) [![Files][82]](<>)

<img height="80"><img src="https://raw.githubusercontent.com/easyScience/easyCrystallography/develop/resources/images/ec_logo.svg" height="65">

**easyCrystallography** is a library that can be used for the generation and manipulation of crystal structures.

## Install

**easyCrystallography** can be downloaded using pip:

```pip install easyCrystallography```

Or direct from the repository:

```pip install https://github.com/easyScience/easyCrystallography```

## Test

After installation, launch the test suite:

```python -m pytest```

[//]: # (## Documentation)

[//]: # ()
[//]: # (Documentation can be found at:)

[//]: # ()
[//]: # ([https://easyScience.github.io/easyCore]&#40;https://easyScience.github.io/easyCore&#41;)

## Contributing
We absolutely welcome contributions. **easyCore** is maintained by the ESS and on a volunteer basis and thus we need to foster a community that can support user questions and develop new features to make this software a useful tool for all users while encouraging every member of the community to share their ideas.

## License
While **easyCore** is under the BSD-3 license

<!---CI Build Status--->

[20]: https://github.com/easyScience/easyCrystallography/workflows/CI%20using%20pip/badge.svg

[21]: https://github.com/easyScience/easyCrystallography/actions


<!---Release--->

[32]: https://img.shields.io/pypi/v/easysciencecore?color=green

[33]: https://pypi.org/project/easyCrystallography


<!---License--->

[50]: https://img.shields.io/github/license/easyScience/easyCrystallography.svg

[51]: https://github.com/easyScience/easyCrystallography/blob/master/LICENSE.md


<!---Downloads--->

[70]: https://img.shields.io/pypi/dm/easyCrystallography.svg

[71]: https://pypi.org/project/easyCrystallography

<!---Code statistics--->

[80]: https://tokei.rs/b1/github/easyScience/easyCrystallography

[81]: https://tokei.rs/b1/github/easyScience/easyCrystallography?category=code

[82]: https://tokei.rs/b1/github/easyScience/easyCrystallography?category=files

[83]: https://www.codefactor.io/repository/github/easyscience/easyCrystallography/badge

[84]: https://www.codefactor.io/repository/github/easyscience/easyCrystallography

[85]: https://img.shields.io/codecov/c/github/easyScience/easyCrystallography?color=green

[86]: https://app.codecov.io/gh/easyScience/easyCrystallography/
